@@ -7,7 +7,7 @@ import pandas as pd
 import pytest
 import verde as vd
 import xarray as xr
-from nptyping import NDArray
+from numpy.typing import NDArray
 
 from invert4geom import inversion
 
@@ -56,12 +56,12 @@ def dummy_misfit_df(regional: bool = True) -> pd.DataFrame:
             100,
         ],
         "upward": [20, 20, 20, 20],
-        "observed_grav": [6.5, 6.8, 7.2, 8.0],
-        "forward_grav": [7.0, 7.0, 7.0, 7.0],
+        "gravity_anomaly": [6.5, 6.8, 7.2, 8.0],
+        "starting_gravity": [7.0, 7.0, 7.0, 7.0],
     }
     df = pd.DataFrame(data)
     # calculate misfit -> [0.5, -0.2, 0.2, 2.0]
-    df["misfit"] = df.observed_grav - df.forward_grav
+    df["misfit"] = df.gravity_anomaly - df.starting_gravity
     # set regional component of misfit
     if regional is True:
         df["reg"] = [3, 2, 1, 0]
@@ -70,13 +70,13 @@ def dummy_misfit_df(regional: bool = True) -> pd.DataFrame:
     # calculate residual component
     df["res"] = df.misfit - df.reg
     # without regional
-    #    northing  easting  upward  observed_grav  forward_grav  misfit  reg  res
+    #    northing  easting  upward  gravity_anomaly  starting_gravity  misfit  reg  res
     # 0       200     -100      20            6.5           7.0    -0.5    0 -0.5
     # 1       200      100      20            6.8           7.0    -0.2    0 -0.2
     # 2       400     -100      20            7.2           7.0     0.2    0  0.2
     # 3       400      100      20            8.0           7.0     1.0    0  1.0
     # with regional
-    #    northing  easting  upward  observed_grav  forward_grav  misfit  reg  res
+    #    northing  easting  upward  gravity_anomaly  starting_gravity  misfit  reg  res
     # 0       200     -100      20            6.5           7.0    -0.5    3 -3.5
     # 1       200      100      20            6.8           7.0    -0.2    2 -2.2
     # 2       400     -100      20            7.2           7.0     0.2    1 -0.8
@@ -128,7 +128,7 @@ def dummy_jacobian() -> NDArray:
     """
     grav = dummy_df()
     prisms_layer = dummy_prism_layer_flat()
-    prisms_properties = inversion.prism_properties(prisms_layer, method="itertools")
+    prisms_properties = inversion._prism_properties(prisms_layer, method="itertools")
     jac = np.empty(
         (len(grav), prisms_layer.top.size),
         dtype=np.float64,
@@ -149,7 +149,7 @@ def dummy_jacobian_square() -> NDArray:
     """
     grav = dummy_df_big()
     prisms_layer = dummy_prism_layer_flat()
-    prisms_properties = inversion.prism_properties(prisms_layer, method="itertools")
+    prisms_properties = inversion._prism_properties(prisms_layer, method="itertools")
     jac = np.empty(
         (len(grav), prisms_layer.top.size),
         dtype=np.float64,
@@ -292,15 +292,18 @@ def test_grav_column_der():
         prism_density=np.array([2670]),
     )[0]
     # harmonica prism approximation
-    step = 0.000001
+    step = 1e-3
     hm_dg_z = (
         hm.prism_gravity(
-            (20, 20, 100), (0, 5, 0, 5, -10, -10 + step), 2670, field="g_z"
+            coordinates=(20, 20, 100),
+            prisms=(0, 5, 0, 5, -10, -10 + step),
+            density=2670,
+            field="g_z",
         )
         / step
     )
     # test that the derivative matches a small prism approximation from
-    assert dg_z == pytest.approx(hm_dg_z, rel=1e-3)
+    assert dg_z == pytest.approx(hm_dg_z, rel=1e-2)
 
 
 @pytest.mark.use_numba()
@@ -334,12 +337,12 @@ def test_jacobian_annular():
 
 def test_prism_properties():
     """
-    test the prism_properties function
+    test the _prism_properties function
     """
     prisms_layer = dummy_prism_layer()
-    itertools_result = inversion.prism_properties(prisms_layer, method="itertools")
-    forloops_result = inversion.prism_properties(prisms_layer, method="forloops")
-    generator_result = inversion.prism_properties(prisms_layer, method="generator")
+    itertools_result = inversion._prism_properties(prisms_layer, method="itertools")
+    forloops_result = inversion._prism_properties(prisms_layer, method="forloops")
+    generator_result = inversion._prism_properties(prisms_layer, method="generator")
     # test that the prism properties are the same with 3 methods
     np.array_equal(itertools_result, forloops_result)
     np.array_equal(itertools_result, generator_result)
@@ -349,11 +352,11 @@ def test_prism_properties():
 
 def test_prism_properties_error():
     """
-    test the prism_properties function raises the correct error
+    test the _prism_properties function raises the correct error
     """
     prisms_layer = dummy_prism_layer()
     with pytest.raises(ValueError, match="method must be"):
-        inversion.prism_properties(prisms_layer, method="wrong_input")
+        inversion._prism_properties(prisms_layer, method="wrong_input")
 
 
 @pytest.mark.use_numba()
@@ -363,7 +366,7 @@ def test_jacobian_prism():
     """
     grav = dummy_df()
     prisms_layer = dummy_prism_layer()
-    prisms_properties = inversion.prism_properties(prisms_layer, method="itertools")
+    prisms_properties = inversion._prism_properties(prisms_layer, method="itertools")
     jac = np.empty(
         (len(grav), prisms_layer.top.size),
         dtype=np.float64,
@@ -549,25 +552,26 @@ def test_update_l2_norms_updated_delta_l2_norm():
 
 def test_end_inversion_first_iteration():
     """
-    Test that the inversion is not terminated in the first iteration.
+    Test that the inversion is not terminated in the first iteration even if the L2 norm
+    is below the tolerance.
     """
     iteration_number = 1
     max_iterations = 100
-    l2_norm = 1.0
-    starting_l2_norm = 1.0
-    l2_norm_tolerance = 0.1
+    l2_norms = [1.0]
+    l2_norm_tolerance = 2.0
     delta_l2_norm = 0.01
     previous_delta_l2_norm = 0.01
     delta_l2_norm_tolerance = 0.01
+    perc_increase_limit = 0.20
     end, termination_reason = inversion.end_inversion(
         iteration_number,
         max_iterations,
-        l2_norm,
-        starting_l2_norm,
+        l2_norms,
         l2_norm_tolerance,
         delta_l2_norm,
         previous_delta_l2_norm,
         delta_l2_norm_tolerance,
+        perc_increase_limit,
     )
     assert not end
     assert termination_reason == []
@@ -577,10 +581,9 @@ def test_end_inversion_l2_norm_increasing():
     """
     Test that the inversion is terminated when L2 norm increases beyond a limit.
     """
-    iteration_number = 2
+    iteration_number = 3
     max_iterations = 100
-    l2_norm = 1.3
-    starting_l2_norm = 1.0
+    l2_norms = [1.0, 1.15, 1.21]
     l2_norm_tolerance = 0.1
     delta_l2_norm = 0.01
     previous_delta_l2_norm = 0.01
@@ -589,8 +592,7 @@ def test_end_inversion_l2_norm_increasing():
     end, termination_reason = inversion.end_inversion(
         iteration_number,
         max_iterations,
-        l2_norm,
-        starting_l2_norm,
+        l2_norms,
         l2_norm_tolerance,
         delta_l2_norm,
         previous_delta_l2_norm,
@@ -607,21 +609,21 @@ def test_end_inversion_delta_l2_norm_tolerance():
     """
     iteration_number = 2
     max_iterations = 100
-    l2_norm = 1.0
-    starting_l2_norm = 1.0
+    l2_norms = [1.0, 1.0]
     l2_norm_tolerance = 0.1
     delta_l2_norm = 0.01
     previous_delta_l2_norm = 0.01
     delta_l2_norm_tolerance = 0.01
+    perc_increase_limit = 0.20
     end, termination_reason = inversion.end_inversion(
         iteration_number,
         max_iterations,
-        l2_norm,
-        starting_l2_norm,
+        l2_norms,
         l2_norm_tolerance,
         delta_l2_norm,
         previous_delta_l2_norm,
         delta_l2_norm_tolerance,
+        perc_increase_limit,
     )
     assert end
     assert "delta l2-norm tolerance" in termination_reason
@@ -633,21 +635,21 @@ def test_end_inversion_l2_norm_tolerance():
     """
     iteration_number = 2
     max_iterations = 100
-    l2_norm = 0.05
-    starting_l2_norm = 1.0
+    l2_norms = [1.0, 0.05]
     l2_norm_tolerance = 0.1
     delta_l2_norm = 0.01
     previous_delta_l2_norm = 0.01
     delta_l2_norm_tolerance = 0.01
+    perc_increase_limit = 0.20
     end, termination_reason = inversion.end_inversion(
         iteration_number,
         max_iterations,
-        l2_norm,
-        starting_l2_norm,
+        l2_norms,
         l2_norm_tolerance,
         delta_l2_norm,
         previous_delta_l2_norm,
         delta_l2_norm_tolerance,
+        perc_increase_limit,
     )
     assert end
     assert "l2-norm tolerance" in termination_reason
@@ -660,21 +662,21 @@ def test_end_inversion_max_iterations():
     """
     iteration_number = 101
     max_iterations = 100
-    l2_norm = 0.5
-    starting_l2_norm = 1.0
+    l2_norms = [1.0, 0.5]
     l2_norm_tolerance = 0.1
     delta_l2_norm = 0.01
     previous_delta_l2_norm = 0.01
     delta_l2_norm_tolerance = 0.01
+    perc_increase_limit = 0.20
     end, termination_reason = inversion.end_inversion(
         iteration_number,
         max_iterations,
-        l2_norm,
-        starting_l2_norm,
+        l2_norms,
         l2_norm_tolerance,
         delta_l2_norm,
         previous_delta_l2_norm,
         delta_l2_norm_tolerance,
+        perc_increase_limit,
     )
     assert end
     assert "max iterations" in termination_reason
@@ -695,7 +697,6 @@ def test_update_gravity_and_misfit_forward_gravity():
     updated_gravity_df = inversion.update_gravity_and_misfit(
         gravity_df=gravity_df_copy,
         prisms_ds=dummy_prism_layer(),
-        input_grav_column="observed_grav",
         iteration_number=1,
     )
     # Check that 'iter_1_forward_grav' column is created
@@ -729,7 +730,6 @@ def test_update_gravity_and_misfit_forward_gravity_regional():
     updated_gravity_df = inversion.update_gravity_and_misfit(
         gravity_df=gravity_df_copy,
         prisms_ds=dummy_prism_layer(),
-        input_grav_column="observed_grav",
         iteration_number=1,
     )
     # expected_forward_grav = [7.18, 7.18, 7.70, 7.70]
@@ -751,8 +751,8 @@ def test_update_gravity_and_misfit_forward_gravity_regional():
 #     print(gravity_df)
 #     print(prisms_ds)
 #     results = inversion.run_inversion(
-#         input_grav=gravity_df,
-#         input_grav_column="observed_grav",
+#         grav_df=gravity_df,
+#         grav_data_column="observed_grav",
 #         prism_layer=prisms_ds,
 #         max_iterations=3,
 #     )
@@ -786,7 +786,7 @@ def test_update_gravity_and_misfit_forward_gravity_regional():
 #     updated_gravity_df = inversion.update_gravity_and_misfit(
 #         gravity_df=gravity_df_copy,
 #         prisms_ds=dummy_prism_layer(),
-#         input_grav_column="observed_grav",
+#         grav_data_column="observed_grav",
 #         iteration_number=5,
 #     )
 #     # Check that 'iter_5_forward_grav' column is created
